Index: src/gpu/GrPipelineBuilder.h |
diff --git a/src/gpu/GrPipelineBuilder.h b/src/gpu/GrPipelineBuilder.h |
index 09b4f91e7304760e8b386c579bf8af1aeeb25ba7..dbbf98a815a8dedfd418743b61814a3622baa101 100644 |
--- a/src/gpu/GrPipelineBuilder.h |
+++ b/src/gpu/GrPipelineBuilder.h |
@@ -139,10 +139,12 @@ public: |
//// |
/** |
- * This function returns true if the render target destination pixel values will be read for |
- * blending during draw. |
+ * Returns true if this pipeline's color output will be affected by the existing render target |
+ * destination pixel values (meaning we need to be careful with overlapping draws). Note that we |
+ * can conflate coverage and color, so the destination color may still bleed into pixels that |
+ * have partial coverage, even if this function returns false. |
*/ |
- bool willBlendWithDst(const GrPrimitiveProcessor*) const; |
+ bool willColorBlendWithDst(const GrPrimitiveProcessor*) const; |
/** |
* Installs a GrXPFactory. This object controls how src color, fractional pixel coverage, |
@@ -387,7 +389,7 @@ private: |
// |
// canUseFracCoveragePrimProc() - Called in regular skia draw, caches results but only for a |
// specific color and coverage. May be called multiple times |
// willBlendWithDst() - only called by Nvpr, does not cache results |
// GrOptDrawState constructor - never caches results |
/** |
@@ -387,7 +389,7 @@ private: |
// canUseFracCoveragePrimProc() - Called in regular skia draw, caches results but only for a |
// specific color and coverage. May be called multiple times |
- // willBlendWithDst() - only called by Nvpr, does not cache results |
+ // willColorBlendWithDst() - only called by Nvpr, does not cache results |
// GrOptDrawState constructor - never caches results |
/** |